<?php

	/*
		EASYWPRESS THEME SETUP
	*/

	//Crear las opciones del tema
	function setup_theme(){

		//Dar soporte a la imagen destacada del post
		add_theme_support( 'post-thumbnails' );

		// Load regular editor styles into the new block-based editor.
		add_theme_support( 'editor-styles' );

		// Load default block styles.
		add_theme_support( 'wp-block-styles' );

		//Registrar los menus del tema
		register_nav_menus(
			array(
				'top'    => __( 'Top Menu', 'twentyseventeen' ),
				'footer' => __( 'Footer Menu', 'twentyseventeen' ),
			)
		);


		//Declarar los tipos de POST necesarios
		setup_post_types();

		//Definir las paginas por defecto
		setup_pages();

		//Definir los menus por defecto
		setup_menus();

	}



	//Crear las páginas por defecto
	function setup_pages(){

		$json_file = get_theme_file_path('inc/theme-default-pages.json');
		$json_pages = file_get_contents($json_file);
		$pages = json_decode($json_pages, true);

		foreach($pages[0]['pages'] as $page):

			$page_check = get_page_by_title($page['title'], OBJECT, $page['type']);

			$new_page = array(
		        'post_type' => $page['type'],
		        'post_title' => $page['title'],
		        'post_name' => $page['slug'],
		        'post_excerpt' => $page['excerpt'],
		        'post_content' => $page['content'],
		        'post_status' => 'publish',
		        'post_author' => 1,
		    );

		    if(!isset($page_check->ID)):
		    	$new_page_id = wp_insert_post($new_page);
		    else:
		    	$new_page_id = $page_check->ID;
		    endif;


		    if(array_key_exists('template', $page)):
		    	update_post_meta($new_page_id, '_wp_page_template', $page['template']);
		    endif;

		endforeach;

	}


	//Crear los tipos de POST específicos
	function setup_post_types(){

		setup_homesection();
		setup_testimonial();
		setup_work();
		setup_service();

	}


	//Crear los menus de navegación por defecto
	function setup_menus(){

		$run_menu_maker_once = get_option('menu_check');

    	if ( ! $run_menu_maker_once ):

    		$primary_menu_items = array(
	            'Portada'  =>  '/',
	            'Nosotros' =>  'nosotros',        
	            'Servicios'  =>  'servicios',
	            'Portafolio'   =>  'trabajos',
	            'Contacto'    =>  'contacto' // You need to setup your logout url using wp_logout()
	        );
	        generate_site_nav_menu( 'Top Menu', $primary_menu_items, 'top' );

    	endif;

	}


	/*
		CREACION DE LOS TIPOS DE POSTS
	*/
	function setup_testimonial(){

		$labels = array(
			'name' => _x( 'Testimonios de clientes', 'post type general name' ),
	        'singular_name' => _x( 'Testimonio', 'post type singular name' ),
	        'add_new' => _x( 'Añadir nuevo', 'testimonio' ),
	        'add_new_item' => __( 'Añadir nuevo Testimonio' ),
	        'edit_item' => __( 'Editar Testimonio' ),
	        'new_item' => __( 'Nuevo Testimonio' ),
	        'view_item' => __( 'Ver Testimonio' ),
	        'search_items' => __( 'Buscar Testimonio' ),
	        'not_found' =>  __( 'No se han encontrado Testimonios' ),
	        'not_found_in_trash' => __( 'No se han encontrado Testimonios en la papelera' ),
	        'parent_item_colon' => ''
	    );

	    // Creamos un array para $args
	    $args = array( 'labels' => $labels,
	        'public' => true,
	        'publicly_queryable' => true,
	        'show_ui' => true,
	        'query_var' => true,
	        'rewrite' => true,
	        'capability_type' => 'post',
	        'hierarchical' => false,
	        'menu_position' => null,
	        'supports' => array( 'title', 'editor', 'thumbnail', 'page-attributes' )
	    );
	 
	    register_post_type( 'testimonio', $args );

	}


	function setup_work(){

		$labels = array(
			'name' => _x( 'Trabajos realizados', 'post type general name' ),
	        'singular_name' => _x( 'Trabajo', 'post type singular name' ),
	        'add_new' => _x( 'Añadir nuevo', 'trabajo' ),
	        'add_new_item' => __( 'Añadir nuevo Trabajo' ),
	        'edit_item' => __( 'Editar Trabajo' ),
	        'new_item' => __( 'Nuevo Trabajo' ),
	        'view_item' => __( 'Ver Trabajo' ),
	        'search_items' => __( 'Buscar Trabajo' ),
	        'not_found' =>  __( 'No se han encontrado Trabajos' ),
	        'not_found_in_trash' => __( 'No se han encontrado Trabajos en la papelera' ),
	        'parent_item_colon' => ''
	    );

	    // Creamos un array para $args
	    $args = array( 'labels' => $labels,
	        'public' => true,
	        'publicly_queryable' => true,
	        'show_ui' => true,
	        'query_var' => true,
	        'rewrite' => true,
	        'capability_type' => 'post',
	        'hierarchical' => false,
	        'menu_position' => null,
	        'supports' => array( 'title', 'thumbnail', 'page-attributes' )
	    );
	 
	    register_post_type( 'work', $args ); /* Registramos y a funcionar */

	}


	function setup_service(){

		$labels = array(
			'name' => _x( 'Servicios', 'post type general name' ),
	        'singular_name' => _x( 'Servicios', 'post type singular name' ),
	        'add_new' => _x( 'Añadir nuevo', 'servicio' ),
	        'add_new_item' => __( 'Añadir nuevo Servicio' ),
	        'edit_item' => __( 'Editar Servicio' ),
	        'new_item' => __( 'Nuevo Servicio' ),
	        'view_item' => __( 'Ver Servicio' ),
	        'search_items' => __( 'Buscar Servicio' ),
	        'not_found' =>  __( 'No se han encontrado Servicios' ),
	        'not_found_in_trash' => __( 'No se han encontrado Servicios en la papelera' ),
	        'parent_item_colon' => ''
	    );

	    // Creamos un array para $args
	    $args = array( 'labels' => $labels,
	        'public' => true,
	        'publicly_queryable' => true,
	        'show_ui' => true,
	        'query_var' => true,
	        'rewrite' => true,
	        'capability_type' => 'post',
	        'hierarchical' => false,
	        'menu_position' => null,
	        'supports' => array( 'title', 'excerpt', 'page-attributes' )
	    );
	 
	    register_post_type( 'service', $args ); /* Registramos y a funcionar */

	}


	function setup_worker(){

		$labels = array(
			'name' => _x( 'Trabajador', 'post type general name' ),
	        'singular_name' => _x( 'Trabajadores', 'post type singular name' ),
	        'add_new' => _x( 'Añadir nuevo', 'trabajador' ),
	        'add_new_item' => __( 'Añadir nuevo Trabajador' ),
	        'edit_item' => __( 'Editar Trabajador' ),
	        'new_item' => __( 'Nuevo Trabajador' ),
	        'view_item' => __( 'Ver Trabajador' ),
	        'search_items' => __( 'Buscar Trabajador' ),
	        'not_found' =>  __( 'No se han encontrado Trabajadores' ),
	        'not_found_in_trash' => __( 'No se han encontrado Trabajadores en la papelera' ),
	        'parent_item_colon' => ''
	    );

	    // Creamos un array para $args
	    $args = array( 'labels' => $labels,
	        'public' => true,
	        'publicly_queryable' => true,
	        'show_ui' => true,
	        'query_var' => true,
	        'rewrite' => true,
	        'capability_type' => 'post',
	        'hierarchical' => false,
	        'menu_position' => null,
	        'supports' => array( 'title', 'thumbnail', 'editor', 'excerpt', 'page-attributes' )
	    );
	 
	    register_post_type( 'worker', $args ); /* Registramos y a funcionar */

	}


	function setup_homesection(){

		$labels = array(
			'name' => _x( 'Sección de portada', 'post type general name' ),
	        'singular_name' => _x( 'Sección', 'post type singular name' ),
	        'add_new' => _x( 'Añadir nuevo', 'home-section' ),
	        'add_new_item' => __( 'Añadir nueva sección' ),
	        'edit_item' => __( 'Editar Sección' ),
	        'new_item' => __( 'Nueva Sección' ),
	        'view_item' => __( 'Ver Sección' ),
	        'search_items' => __( 'Buscar Sección' ),
	        'not_found' =>  __( 'No se han encontrado Secciones' ),
	        'not_found_in_trash' => __( 'No se han encontrado Secciones en la papelera' ),
	        'parent_item_colon' => ''
	    );

	    // Creamos un array para $args
	    $args = array( 'labels' => $labels,
	        'public' => true,
	        'publicly_queryable' => true,
	        'show_ui' => true,
	        'query_var' => true,
	        'rewrite' => true,
	        'capability_type' => 'post',
	        'hierarchical' => false,
	        'menu_position' => null,
	        'supports' => array( 'title', 'editor', 'excerpt', 'thumbnail', 'page-attributes' )
	    );
	 
	    register_post_type( 'home-section', $args );

	}



	function generate_site_nav_menu_item( $term_id, $title, $url ) {
    
	    wp_update_nav_menu_item($term_id, 0, array(
	        'menu-item-title'   =>  sprintf( __('%s', 'text_domain'), $title ),
	        'menu-item-url'     =>  home_url( '/' . $url ), 
	        'menu-item-status'  =>  'publish'
	    ) );
	    
	}

	function generate_site_nav_menu( $menu_name, $menu_items_array, $location_target ) {
    
	    $menu_primary = $menu_name;
	    wp_create_nav_menu( $menu_primary );
	    $menu_primary_obj = get_term_by( 'name', $menu_primary, 'nav_menu' );
	    
	    foreach( $menu_items_array as $page_name => $page_location ){
	        generate_site_nav_menu_item( $menu_primary_obj->term_id, $page_name, $page_location );
	    }
	    
	    $locations_primary_arr = get_theme_mod( 'nav_menu_locations' );
	    $locations_primary_arr[$location_target] = $menu_primary_obj->term_id;
	    set_theme_mod( 'nav_menu_locations', $locations_primary_arr );
	        
	    update_option( 'menu_check', true );
	    
	}

?>